/*
 * Copyright 2021 Chris Banes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

@file:Suppress("NOTHING_TO_INLINE")

package dev.chrisbanes.internal

import androidx.compose.ui.graphics.Color
import kotlin.random.Random

inline fun parameterizedParams(): List<Array<Any>> = emptyList()

inline fun <reified T> List<Array<T>>.combineWithParameters(
    vararg values: T
): List<Array<T>> {
    if (isEmpty()) {
        return values.map { arrayOf(it) }
    }

    return fold(emptyList()) { acc, args ->
        val result = acc.toMutableList()
        values.forEach { v ->
            result += ArrayList<T>().apply {
                addAll(args)
                add(v)
            }.toTypedArray()
        }
        result.toList()
    }
}

fun randomColor() = Color(
    alpha = 1f,
    red = Random.nextFloat(),
    green = Random.nextFloat(),
    blue = Random.nextFloat(),
)
